This section will allow you to install a proper local environment step by step for Ecolyo application using VSCode IDE.

## VSCode

### Install VSCode

Installation for VSCode can be found here: [Installation of VSCode](https://code.visualstudio.com/).

### Extensions

Installation of Extention is explained here: [Installation of Extensions](https://code.visualstudio.com/docs/editor/extension-gallery).

Here are the list of important extensions to install:

- Prettier - Code formatter
- ES7 React/Redux/GraphQL/React-Native snippets
- GitLens - Git supercharged
- Markdown Preview

Optional extensions:

- Bracket Pair Colorizer 2
- CSS Peek
- Auto Rename Tag
- indent-rainbow
- TabOut
- Liveshare (pair programming extension)

### User settings

Open the project with VSCode and add the following code into .vscode/settings.json:

```
{
  "workbench.colorCustomizations": {
     /* Put anything you like here */
  },
  "editor.snippetSuggestions": "top",
  "editor.tabSize": 2,
  "editor.formatOnSave": true,
  "diffEditor.ignoreTrimWhitespace": false,
  "window.zoomLevel": 0,
  "gitlens.advanced.messages": {
      "suppressShowKeyBindingsNotice": true
  },
  "breadcrumbs.enabled": true,
  "workbench.settings.editor": "json",
  "editor.tabSize": 2,
  "editor.formatOnSave": true,
  "editor.formatOnPaste": true
}
```

If this file is not empty, you can simply add the following lines to it:

```
  "gitlens.advanced.messages": {
    "suppressShowKeyBindingsNotice": true
  },
  "breadcrumbs.enabled": true,
  "workbench.settings.editor": "json",
  "editor.formatOnSave": true,
  "diffEditor.ignoreTrimWhitespace": false,
  "window.zoomLevel": 0,
```

## Git

The project is using GitLab, you will need to install Git to checkout the projet.
Installation for Git can be found here: [Installation of Git](https://git-scm.com/).

## Node

For this project, Node version 14 is required.Download [node-v14](https://nodejs.org/en/download/).

Node.js® is a JavaScript runtime built on Chrome's V8 JavaScript engine.

## Yarn

Yarn is used as package manager for this projet. Feel free to use the one you prefere but we advice to install yarn as all the documentation is described with this package manager.
Installation for yarn can be found here: [Installation of Yarn](https://classic.yarnpkg.com/fr/docs/install/).

## Docker

Docker is a tool designed to make it easier to create, deploy, and run applications by using containers. Containers allow a developer to package up an application with all of the parts it needs, such as libraries and other dependencies, and ship it all out as one package. By doing so, thanks to the container, the developer can rest assured that the application will run on any other Linux machine regardless of any customized settings that machine might have that could differ from the machine used for writing and testing the code.

### Install Docker

Installation of Docker can be found here: [Installation of Docker](https://www.docker.com/get-started).

### Install Docker-Compose

Installation of Docker-Compose (according to your OS) is explained here: [Installation of Docker-Compose](https://docs.docker.com/compose/install/).

### Install WSL

First open Powershell as administrator and launch the following command :

```powershell
dism.exe /online /enable-feature /featurename:Microsoft-Windows-Subsystem-Linux /all /norestart
```

This command will install WSL on your computer. After this, you'll need to **reboot**.

### Upgrade to WSL 2

If you're on WSL 1 and want to upgrade to WSL 2, here is the process :

Open an elevated powershell and paste the following command :

```
dism.exe /online /enable-feature /featurename:Microsoft-Windows-Subsystem-Linux /all /norestart
```

Then, enable the Virtual Machine Platform optional feature.

```
dism.exe /online /enable-feature /featurename:VirtualMachinePlatform /all /norestart
```

Now restart your computer to apply these features. Once it's done, open an elevated powershell again and set the default wsl version to 2

```
wsl --set-default-version 2
```

You might see this message after running the command above:

> :bulb: WSL 2 requires an update to its kernel component. For information please visit https://aka.ms/wsl2kernel.

If you do, please follow the link [https://aka.ms/wsl2kernel](https://aka.ms/wsl2kernel) and install the MSI from that page on Microsoft's documentation to install a Linux kernel on your machine for WSL 2 to use. Once you have the kernel installed, please run the wsl --set-default-version 2 command again and it should complete successfully without showing the message.

### Install your Linux distribution

After reboot, open the microsoft store and install the distribution of your choice (for example : Ubuntu 20.04 LTS). Once it's done, open it and after a few minutes you'll be prompted for the creation of a user account.

To make sure it's correctly installed and working, you can open Powershell and paste the following command :

```powershell
wsl.exe --list --running
```

Now you should see the name of your distribution in the list.

### Setup your distribution

Start updating the packages list by typing :

```
sudo apt update
```

Install nodejs using the apt package manager

```
sudo apt install
```

To verify the Installation execute the following command :

```
nodejs --version
```

To be able to download npm package, you need to install the npm, the Node.js package manager. To do so type :

```
sudo apt install npm
```

To verify the npm Install check using the command :

```
npm --version
```

To Downlaod and Setup Yarn

```
sudo apt install yarn
```

To check the Installed version of Yarn :

```
yarn --version
```

Now you'll probably be in version 0.23+git, if so you'll have to upgrade to 1.22 to make everything work properly.
In order to achieve this, you'll have to launch several commands :

```
sudo apt-get remove cmdtest
sudo apt autoremove
sudo apt-get update
sudo apt install curl -y
curl -o- -L https://yarnpkg.com/install.sh | bash
source ~/.bashrc
```

Now you should be at least in version ^1.22 and ready to go on.
